"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toRGB = void 0;
const _1 = require(".");
/**
 * Converts a Hexadecimal CSS color value into an array object with format [r,g,b].
 * Each array element will contain the corresponding 0-255 value respectively.
 * @param value string Hexadecimal CSS color value
 * @returns string[]
 */
const toRGB = (value) => {
    if (value.charAt(0) === '#') {
        value = (0, _1.unhash)(value);
    }
    if (value.length === 3) {
        value = (0, _1.expand)(value);
    }
    if (value.length < 3 || value.length > 3 && value.length < 6 || value.length > 6) {
        throw new Error("Value is not a correct hexadecimal color value.");
    }
    if (!(0, _1.isColor)(value)) {
        throw new Error("Value is not a correct hexadecimal color value.");
    }
    const parsed = parseInt(value, 16);
    const r = (parsed >> 16) & 255;
    const g = (parsed >> 8) & 255;
    const b = parsed & 255;
    return [r, g, b];
};
exports.toRGB = toRGB;
exports.default = exports.toRGB;
